@@ -25,4 +25,8 @@
 #  include <arch/solaris/prototypes.h>
 #endif
 
+#if defined (HAVE_TIME_H)
+#  define METAHTML_PROFILER 1
+#endif
+
 
