@@ -101,7 +101,9 @@
     "database-save-record" "database-load-record" "database-save-package"
     "database-delete-record" "database-first-key" "database-next-key"
     "database-first-match" "database-next-match" "database-query"
-    "in-package" "with-local-package"
+    "in-package" "with-local-package" "foreach" "array-size" "array-append"
+    "array-add-unique" "layout::page" "layout::left-border"
+    "layout::right-border"
     "example" "simple-fundoc" "complex-fundoc" "prog" "server-push"))
 
 (defun mhtml-build-font-lock-keywords (from-list)
@@ -207,7 +209,7 @@ rigidly along with this one."
      "ul" "ol" "dl" "table" "tr" "td" "center" "a" "form" "select" "caption"
      "applet" "subtable" "in-package" "with-local-package"
      "example" "question" "nested-items-list" "nested-item" "slide" "bullet"
-     "menu" "system-menu"
+     "menu" "system-menu" "foreach" "menu" "system-menu"
      "layout::page" "layout::left-border" "layout::right-border"
      "frameset" "msql::with-open-database" "odbc::with-open-database"
      "dbm::with-open-database" "def-pagelist")
@@ -463,13 +465,14 @@ of the start of the containing expression."
 (put 'odbc::database-query 'mhtml-indent-function 'defun)
 (put 'odbc::database-load-record 'mhtml-indent-function 'defun)
 (put 'odbc::database-save-record 'mhtml-indent-function 'defun)
+(put 'with-open-stream 'mhtml-indent-function 'defun)
 (put 'if 'mhtml-indent-function 2)
 (put 'ifeq 'mhtml-indent-function 3)
 (put 'var-case 'mhtml-indent-function 'defun)
-(put 'set-var 'mhtml-indent-function 'defun)
-(put 'get-var 'mhtml-indent-function 'defun)
-(put 'set-session-var 'mhtml-indent-function 'defun)
-(put 'get-session-var 'mhtml-indent-function 'defun)
+;;; (put 'set-var 'mhtml-indent-function 'defun)
+;;; (put 'get-var 'mhtml-indent-function 'defun)
+;;; (put 'set-session-var 'mhtml-indent-function 'defun)
+;;; (put 'get-session-var 'mhtml-indent-function 'defun)
 (put 'PROG 'mhtml-indent-function 'defun)
 (put 'DATABASE-QUERY 'mhtml-indent-function 'defun)
 (put 'DATABASE-LOAD-RECORD 'mhtml-indent-function 'defun)
@@ -480,13 +483,14 @@ of the start of the containing expression."
 (put 'ODBC::DATABASE-QUERY 'mhtml-indent-function 'defun)
 (put 'ODBC::DATABASE-LOAD-RECORD 'mhtml-indent-function 'defun)
 (put 'ODBC::DATABASE-SAVE-RECORD 'mhtml-indent-function 'defun)
+(put 'WITH-OPEN-STREAM 'mhtml-indent-function 'defun)
 (put 'IF 'mhtml-indent-function 2)
 (put 'IFEQ 'mhtml-indent-function 3)
 (put 'VAR-CASE 'mhtml-indent-function 'defun)
-(put 'SET-VAR 'mhtml-indent-function 'defun)
-(put 'GET-VAR 'mhtml-indent-function 'defun)
-(put 'SET-SESSION-VAR 'mhtml-indent-function 'defun)
-(put 'GET-SESSION-VAR 'mhtml-indent-function 'defun)
+;;; (put 'SET-VAR 'mhtml-indent-function 'defun)
+;;; (put 'GET-VAR 'mhtml-indent-function 'defun)
+;;; (put 'SET-SESSION-VAR 'mhtml-indent-function 'defun)
+;;; (put 'GET-SESSION-VAR 'mhtml-indent-function 'defun)
 
 (defun mhtml-indent-sexp (&optional endpos)
   "Indent each line of the list starting just after point.
