@@ -83,6 +83,10 @@ static void parse_program_args (int argc, char *argv[]);
 static void initialize_engine (void);
 static void fatal (char *format, ...);
 
+#if defined (ISPENGINE)
+#  undef CHECK_ACTIVATION
+#endif
+
 #if defined (CHECK_ACTIVATION)
 extern int check_activation_key (char *key);
 #endif
@@ -108,7 +112,11 @@ main (int argc, char *argv[])
 	   (temp[0] == '/'))
     rawprogname = strdup (temp);
   else
+#if defined (ISPENGINE)
+    rawprogname = strdup ("mhtml.cgi");
+#else
     rawprogname = strdup ("nph-engine");
+#endif
 
   temp = strrchr (rawprogname, '/');
   if (temp != (char *)NULL)
@@ -116,9 +124,9 @@ main (int argc, char *argv[])
   else
     progname = strdup (rawprogname);
 
-#if !defined (BUILDING_WITH_FAST_CGI)
   nph = (strncasecmp (progname, "nph-", 4) == 0);
-#endif
+
+  pagefunc_set_variable ("mhtml::program-name", progname);
 
   parse_program_args (argc, argv);
   initialize_engine ();
@@ -137,16 +145,16 @@ main (int argc, char *argv[])
       if (child != (pid_t) 0)
 	{
 	  int status;
-	  /* In the Parent. */
-	  wait (&status);
+
+	  waitpid (child, &status, 0);
 	}
       else
 	{
 	  char number[20];
 	  sprintf (number, "%d", times_called);
 	  pagefunc_set_variable ("fcgi::times-called", number);
+
 	  process_request ();
-	  fflush (stdout);
 	  _exit (0);
 	}
     }
@@ -186,10 +194,17 @@ initialize_engine (void)
   pagefunc_set_variable ("mime-type::.jpeg", "image/jpeg");
   pagefunc_set_variable ("mime-type::.jpg", "image/jpeg");
   pagefunc_set_variable ("mime-type::.gif", "image/gif");
-  pagefunc_set_variable ("mime-type::.html", "text/html");
   pagefunc_set_variable ("mime-type::.txt", "text/plain");
   pagefunc_set_variable ("mime-type::.mov", "video/quicktime");
   pagefunc_set_variable ("mime-type::.default", "text/plain");
+#if defined (ISPENGINE)
+  pagefunc_set_variable ("mime-type::.html", "metahtml/interpreted");
+  pagefunc_set_variable ("mime-type::.htm", "metahtml/interpreted");
+  pagefunc_set_variable ("mhtml::isp-engine?", "true");
+#else
+  pagefunc_set_variable ("mime-type::.html", "text/html");
+  pagefunc_set_variable ("mime-type::.htm", "text/html");
+#endif
 
   /* The minimum startup documents. */
   pagefunc_set_variable ("mhtml::default-filenames[]",
@@ -200,7 +215,12 @@ Directory.mhtml\ndirectory.mhtml\n\
 index.html\nhome.html");
 
   /* The default extensions for running files through the engine. */
+#if defined (ISPENGINE)
+  pagefunc_set_variable
+    ("mhtml::metahtml-extensions[]", ".mhtml\n.html\n.htm");
+#else
   pagefunc_set_variable ("mhtml::metahtml-extensions[]", ".mhtml");
+#endif
 
   /* Default the value of mhtml::include-prefix to the directory above
      the location of this program.  This empirically seems to be the
@@ -211,10 +231,12 @@ index.html\nhome.html");
   if (temp != (char *)NULL)
     {
       *temp = '\0';
+#if !defined (ISPENGINE)
       temp = strrchr (include_prefix, '/');
 
       if (temp != (char *)NULL)
 	*temp = '\0';
+#endif
     }
 
   pagefunc_set_variable ("mhtml::include-prefix", include_prefix);
@@ -244,6 +266,11 @@ index.html\nhome.html");
 
   if (page && page->buffer)
     page_process_page (page);
+  else
+    {
+      char *ignore = mhtml_evaluate_string ("<engine::initialize>");
+      xfree (ignore);
+    }
 
   if (page)
     page_free_page (page);
@@ -499,7 +526,7 @@ fatal (char *format, ...)
 }
 
 static HTTP_REQUEST *
-engine_make_request (int fd)
+engine_make_request (void)
 {
   HTTP_REQUEST *req = (HTTP_REQUEST *)xmalloc (sizeof (HTTP_REQUEST));
   char *temp;
@@ -622,7 +649,6 @@ engine_make_request (int fd)
 	register int i;
 	char *entry;
 
-
 	for (i = 0; (entry = environ[i]) != (char *)NULL; i++)
 	  {
 	    if (strncmp (entry, "HTTP_", 5) == 0)
@@ -702,14 +728,17 @@ engine_make_request (int fd)
 static void
 process_request (void)
 {
+  /* Handle a single request. */
   int connection = fileno (stdin);
-
-  /* In the child, handle a single request. */
   HTTP_REQUEST *req = (HTTP_REQUEST *)NULL;
   HTTP_RESULT *result = (HTTP_RESULT *)NULL;
 
   /* Okay, read the HTTP request and handle it. */
-  req = engine_make_request (connection);
+  req = engine_make_request ();
+
+#if defined (BUILDING_WITH_FAST_CGI)
+  mhtml_stdout_fileno = 1;
+#endif
 
   mhttpd_mime_headers_to_package (req->headers, "mhttpd-received-headers");
   pagefunc_set_variable ("mhttpd::method", req->method);
@@ -718,6 +747,8 @@ process_request (void)
   pagefunc_set_variable ("mhttpd::location", req->location);
   pagefunc_set_variable ("mhttpd::requester", req->requester);
   pagefunc_set_variable ("mhttpd::requester-addr", req->requester_addr);
+  pagefunc_set_variable ("mhttpd::virtual-host",
+			 (char *)getenv ("HTTP_HOSTNAME"));
 
   if (req && mhttpd_per_request_function)
     {
@@ -761,7 +792,7 @@ process_request (void)
 	      }
 	}
 
-      fwrite (result->page->buffer + i, result->page->bindex - i, 1, stdout);
+      fwrite (result->page->buffer + i, result->page->bindex, 1, stdout);
       fflush (stdout);
     }
 }
