@@ -278,7 +278,7 @@ pf_array_shift (PFunArgs)
   xfree (start_var);
 }
 
-/* <foreach elementvar arrayvar start=X end=X> body </foreach>
+/* <foreach elementvar arrayvar [start=X] [end=X]> body </foreach>
    Perform body with ELEMENTVAR bound to successive memebers of
    ARRAYVAR, starting with the element at START (default 0), and
    ending at END (default <array-size ARRAYVAR>). */
@@ -342,19 +342,27 @@ pf_foreach (PFunArgs)
 		    ((start_index > end_index) && (i >= end_index)));
 		   i += step)
 		{
-		  char *result;
 		  Symbol *element = symbol_remove (element_var);
+		  PAGE *code;
 
 		  symbol_free (element);
 		  element = symbol_intern (element_var);
 		  symbol_add_value (element, array->values[i]);
-		  result = mhtml_evaluate_string (body->buffer);
+		  code = page_copy_page (body);
+		  page_process_page_internal (code);
 
-		  if (result != (char *)NULL)
+		  if (code != (PAGE *)NULL)
 		    {
-		      bprintf_insert (page, start, "%s", result);
-		      start += strlen (result);
-		      free (result);
+		      int broken = (code->attachment != (void *)NULL);
+
+		      if (code->bindex != 0)
+			{
+			  bprintf_insert (page, start, "%s", code->buffer);
+			  start += (code->bindex);
+			}
+
+		      page_free_page (code);
+		      if (broken) break;
 		    }
 		}
 	    }
