@@ -19,6 +19,7 @@ bootstrap_metahtml (int call_initializer_p)
       if (sd != -1)
 	{
 	  Package *pack;
+	  char *temp;
 
 	  symdump_write_string_data
 	    (sd, bootstrap_code_len, &bootstrap_code[0]);
@@ -28,10 +29,14 @@ bootstrap_metahtml (int call_initializer_p)
 	  if (mhtml_user_keywords == (Package *)NULL)
 	    mhtml_user_keywords = symbol_lookup_package ("*user-functions*");
 	  bprintf_free_buffer (symdump_close_string_data (sd));
+
+	  /* Always call <bootstrapper::system-initialize>. */
+	  temp = mhtml_evaluate_string ("<bootstrapper::system-initialize>");
+	  xfree (temp);
+
+	  /* Optionally call <bootstrapper::initialize> */
 	  if (call_initializer_p)
 	    {
-	      char *temp;
-
 	      temp = mhtml_evaluate_string ("<bootstrapper::initialize>");
 	      xfree (temp);
 	    }
