@@ -67,7 +67,7 @@ char *
 database_strerror (void)
 {
   if (gdbm_errno != GDBM_NO_ERROR)
-    return (gdbm_strerror (gdbm_errno));
+    return ((char *)gdbm_strerror (gdbm_errno));
   else
     return ((char *)strerror (errno));
 }
