@@ -28,52 +28,7 @@
    Santa Barbara, CA
    93101  */
 
-#define LANGUAGE_DEFINITIONS_FILE 1
-
-#if defined (HAVE_CONFIG_H)
-#  include <config.h>
-#endif
-
-#if defined (sgi) || defined (Solaris)
-#define d_namlen d_reclen
-#endif
-
-#if defined (__linux__) && !defined (d_namlen)
-#define d_namlen d_reclen
-#endif
-
-#if defined (__WINNT__)
-#  define D_NAMELEN(x) strlen ((x)->d_name)
-#else
-#  define D_NAMELEN(x) (x)->d_namlen
-#endif
-
-#include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <string.h>
-#include <ctype.h>
-#include <sys/types.h>
-#if defined (Solaris)
-#  include <ucbinclude/sys/fcntl.h>
-#  include <ucbinclude/sys/file.h>
-#else
-#  include <sys/file.h>
-#endif /* !Solaris */
-#include <sys/stat.h>
-#include <dirent.h>
-#include <pwd.h>
-#include <sys/time.h>
-#include <signal.h>
-#include <setjmp.h>
-#include <regex.h>
-#include <bprintf/bprintf.h>
-#include <xmalloc/xmalloc.h>
-#include "forms.h"
-#include "session.h"
-#include "pages.h"
-#include "parser.h"
+#include "language.h"
 
 static void pf_get_file_properties (PFunArgs);
 static void pf_set_file_properties (PFunArgs);
@@ -293,12 +248,10 @@ pf_directory_contents (PFunArgs)
 
 	  packname = mhtml_evaluate_string (get_positional_arg (vars, 1));
 	  if ((packname != (char *)NULL) && empty_string_p (packname))
-	    {
-	      free (packname);
-	      packname = strdup ("DEFAULT");
-	    }
+	    package = CurrentPackage;
+	  else
+	    package = symbol_get_package (packname);
 
-	  package = symbol_get_package (packname);
 	  sprintf (buffer, "%s", dirname);
 	  offset = strlen (buffer);
 	  if (buffer[offset - 1] != '/')
