@@ -31,6 +31,14 @@
 
 #define LANGUAGE_DEFINITIONS_FILE 1
 
+#if defined (_GNUC_) && !defined (VOLATILE)
+#  define VOLATILE volatile
+#endif
+
+#if !defined (VOLATILE)
+#  define VOLATILE
+#endif
+
 #include "mhtmlstd.h"
 #include "forms.h"
 #include "session.h"
