@@ -1,4 +1,4 @@
-/* msqldb.c:  MSQL database compatibility layer. */
+/* msqlfuncs.c:  MSQL database compatibility layer. */
 
 /* This file is part of <Meta-HTML>(tm), a system for the rapid
    deployment of Internet and Intranet applications via the use
@@ -34,6 +34,7 @@
 #define DEFAULT_SQL_TRUNCATE_COLUMNS  1
 #define DEFAULT_SQL_PREFIX_TABLENAMES 0
 
+
 PACKAGE_INITIALIZER (initialize_msql_functions)
 
 PFunDesc msqlfunc_table[] =
@@ -52,6 +53,7 @@ PFunDesc msqlfunc_table[] =
   { "MSQL::HOST-DATABASES",	        0, 0, pf_host_databases },
   { "MSQL::DATABASE-TABLES",     	0, 0, pf_database_tables },
   { "MSQL::DATABASE-TABLES-INFO",     	0, 0, pf_database_tables_info },
+  { "MSQL::DATABASE-TABLE-INFO",     	0, 0, pf_database_tables_info },
   { "MSQL::DATABASE-COLUMNS",           0, 0, pf_database_columns },
   { "MSQL::DATABASE-COLUMN-INFO",       0, 0, pf_database_column_info },
   { "MSQL::DATABASE-COLUMNS-INFO",      0, 0, pf_database_columns_info },
@@ -176,6 +178,8 @@ typedef struct
 {
   gsql_result *result;		/* The results of <database-exec-query..> */
   Database *db;			/* Associated database connection. */
+  int index;			/* A unique index number for this cursor within
+				   the stack of cursors for a database. */
 } DBCursor;
 
 static void free_database_cursors (Database *db);
@@ -254,12 +258,13 @@ gsql_fetch_field (gsql_result *result, int i)
 }
 
 static int
-gsql_query (Database *db, char *query)
+gsql_query (Database *db, char *query, int save_errors_p)
 {
-  int status =  msqlQuery(db->sock, query);
+  int status =  msqlQuery (db->sock, query);
   if (status == -1)
     {
-      gsql_save_error_message (db, "msqlQuery");
+      if (save_errors_p)
+	gsql_save_error_message (db, "msqlQuery");
       return (GSQL_ERROR);
     }
   else
