@@ -91,15 +91,6 @@ static void pf_alist_to_package (PFunArgs);
 static void pf_in_package (PFunArgs);
 static void pf_with_local_package (PFunArgs);
 
-/* <if test then else> If eval (test) produces non-zero length text, then... */
-static void pf_if (PFunArgs);
-
-/* <ifeq this that then else> If eval (this) = eval (that), then, else */
-static void pf_ifeq (PFunArgs);
-
-/* <when TEST> body </when> */
-static void pf_when (PFunArgs);
-
 /* <not TEST> --> "true" if TEST is empty, "" otherwise. */
 static void pf_not (PFunArgs);
 
@@ -110,9 +101,6 @@ static void pf_and (PFunArgs);
    all are false. */
 static void pf_or (PFunArgs);
 
-/* <var-case [this=that do-this] ...> Do-this where <get-var THIS> == THAT. */
-static void pf_var_case (PFunArgs);
-
 /* <defmacro macro-name> body </defmacro>
    Store MACRO-NAME as a complex tag.
    Do replacements on %1..%9 and %body in BODY at invocation time. */
@@ -143,11 +131,6 @@ static void pf_undef (PFunArgs);
 /* <function-def foo bar> --> Prints out function defs. */
 static void pf_function_def (PFunArgs);
 
-/* <while test>  body-text ... </while> Do BODY-TEXT while TEST
-   produces non-zero length text. */
-#define PAGE_ITERATOR_MAX_COUNT 500 /* No more than this many times. */
-static void pf_while (PFunArgs);
-
 /* <increment VAR [BY=xx]>  Change the value of VAR by XX. */
 static void pf_increment (PFunArgs);
 
@@ -291,14 +274,9 @@ PFunDesc pagefunc_table[] = {
   { "PACKAGE-DELETE",	0, 0, pf_package_delete },
   { "INCREMENT",	0, 0, pf_increment },
   { "DECREMENT",	0, 0, pf_decrement },
-  { "IF",		0, 0, pf_if },
-  { "IFEQ",		0, 0, pf_ifeq },
-  { "WHEN",		1, 0, pf_when },
   { "NOT",		0, 0, pf_not },
   { "AND",		0, 0, pf_and },
   { "OR",		0, 0, pf_or },
-  { "VAR-CASE",		0, 0, pf_var_case },
-  { "WHILE",		1, 0, pf_while },
   { "DEFMACRO",		1, 0, pf_defmacro },
   { "DEFWEAKMACRO",	1, 0, pf_defweakmacro },
   { "DEFINE-CONTAINER",	1, 0, pf_defmacro },
@@ -957,50 +935,6 @@ pf_package_delete (PFunArgs)
     }
 }
 
-static void
-pf_if (PFunArgs)
-{
-  char *test_clause = mhtml_evaluate_string (get_positional_arg (vars, 0));
-  char *then_clause = get_positional_arg (vars, 1);
-  char *else_clause = get_positional_arg (vars, 2);
-  char *consequence;
-
-  if (!empty_string_p (test_clause))
-    consequence = then_clause;
-  else
-    consequence = else_clause;
-
-  if (consequence != (char *)NULL)
-    bprintf_insert (page, start, "%s", consequence);
-
-  xfree (test_clause);
-}
-
-static void
-pf_ifeq (PFunArgs)
-{
-  char *left_clause = mhtml_evaluate_string (get_positional_arg (vars, 0));
-  char *right_clause = mhtml_evaluate_string (get_positional_arg (vars, 1));
-  char *then_clause = get_positional_arg (vars, 2);
-  char *else_clause = get_positional_arg (vars, 3);
-  int caseless_p = var_present_p (vars, "CASELESS");
-  char *consequence;
-
-  if (((empty_string_p (left_clause)) && (empty_string_p (right_clause))) ||
-      ((left_clause && right_clause) &&
-       (((!caseless_p) && (strcmp (left_clause, right_clause) == 0)) ||
-	((caseless_p) && (strcasecmp (left_clause, right_clause) == 0)))))
-    consequence = then_clause;
-  else
-    consequence = else_clause;
-
-  if (consequence != (char *)NULL)
-    bprintf_insert (page, start, "%s", consequence);
-
-  xfree (left_clause);
-  xfree (right_clause);
-}
-
 #if defined (MHTML_ARITHMETIC)
 
 /* Arithmetic operations.  This is pretty ugly. */
@@ -1379,17 +1313,6 @@ pf_random (PFunArgs)
 
   bprintf_insert (page, start, "%d", result);
 }
-  
-static void
-pf_when (PFunArgs)
-{
-  char *test = mhtml_evaluate_string (get_positional_arg (vars, 0));
-
-  if (!empty_string_p (test))
-    bprintf_insert (page, start, "%s", body->buffer);
-
-  if (test) free (test);
-}
 
 static void
 pf_not (PFunArgs)
@@ -1462,118 +1385,6 @@ pf_or (PFunArgs)
     }
 }
 
-static void
-pf_while (PFunArgs)
-{
-  char *test = get_positional_arg (vars, 0);
-  int iteration_count = 0;
-  char *limit_string = pagefunc_get_variable ("mhtml::iteration-limit");
-  int limit = limit_string ? atoi (limit_string) : PAGE_ITERATOR_MAX_COUNT;
-  char *result;
-
-  while (((result = mhtml_evaluate_string (test)) != (char *)NULL) &&
-	 (result[0] != '\0'))
-    {
-      PAGE *code;
-
-      iteration_count++;
-
-      if (iteration_count > limit)
-	break;
-
-      code = page_copy_page (body);
-      page_process_page_internal (code);
-
-      if ((code != (PAGE *)NULL) && (code->bindex != 0))
-	{
-	  bprintf_insert (page, start, "%s", code->buffer);
-	  start += (code->bindex);
-
-	  *newstart = start;
-	}
-
-      if (code != (PAGE *)NULL)
-	page_free_page (code);
-
-      free (result);
-    }
-
-  if (result) free (result);
-}
-
-static void
-pf_var_case (PFunArgs)
-{
-  register int i = 0;
-  char **names = get_vars_names (vars);
-  char **vals = get_vars_vals (vars);
-  static char *nullval = "";
-  char *default_action = (char *)NULL;
-  int clause_found = 0;
-
-  if (names != (char **)NULL)
-    {
-      while (1)
-	{
-	  char *name = (char *)NULL;
-	  char *case_value = (char *)NULL;
-	  char *page_value = (char *)NULL;
-	  char *action = (char *)NULL;
-
-	  if ((names[i] == (char *)NULL) || (names[i + 1] == (char *)NULL))
-	    break;
-
-	  name = mhtml_evaluate_string (names[i]);
-	  case_value = mhtml_evaluate_string (vals[i]);
-	  page_value = pagefunc_get_variable (name);
-	  action = names[i + 1];
-	  i += 2;
-
-	  if (name != (char *)NULL)
-	    {
-	      /* Check for special "default" case. */
-	      if (strcasecmp (name, "default") == 0)
-		{
-		  default_action = action;
-		  if (case_value) free (case_value);
-		  if (page_value) free (page_value);
-		  free (name);
-		  continue;
-		}
-	      free (name);
-	    }
-
-	  /* Check the value against the page value. */
-	  if (empty_string_p (page_value))
-	    {
-	      page_value = nullval;
-	    }
-
-	  if (empty_string_p (case_value))
-	    {
-	      if (case_value) free (case_value);
-	      case_value = nullval;
-	    }
-
-	  if ((page_value == case_value) ||
-	      (strcasecmp (page_value, case_value) == 0))
-	    {
-	      clause_found = 1;
-	      if (action != (char *)NULL)
-		bprintf_insert (page, start, "%s", action);
-
-	      if (case_value != nullval) free (case_value);
-	      break;
-	    }
-
-	  if (case_value != nullval) free (case_value);
-	}
-
-      if (default_action && !clause_found)
-	bprintf_insert (page, start, "%s", default_action);
-    }
-}
-
 static void
 change_increment (PFunArgs, int default_amount)
 {
