@@ -55,6 +55,14 @@ extern PAGE *page_read_template (char *filename);
    characters added or deleted.  THIS is a regular expression. */
 extern int page_subst_in_page (PAGE *page, char *this, char *with_that);
 
+/* Do some substitutions in PAGE; that is, substitute THIS WITH_THAT in PAGE.
+   The substitutions happen in place, and the return value is the number of
+   characters added or deleted before PIVOT.  THIS is a regular expression.
+   PIVOT is a pointer to an integer which is adjusted depending on the number
+   of characters added or deleted before it.  An NULL pointer means skip this
+   calculation. */
+extern int page_subst_in_page_pivot (PAGE *page, char *this, char *with_that, int *pivot);
+
 /* Return the offset of STRING in PAGE.  Start the search at START.
    The absolute index is returned, not the offset from START, so
    the value is suitable for resubmission to this function as START value.
@@ -181,4 +189,13 @@ extern int page_complex_tag_bounds (PAGE *page, char *tag,
 extern char *page_complex_tag_extract (PAGE *page, char *tag,
 				       int *startp, int *endp);
 
+/* Find out if <indicator> belongs to the complex <tag>, and return 3 values:
+      1) The output of the function is non-zero if INDICATOR was found,
+         It is 1 if the indicator was found and it was ours, -1 if the
+	 indicator was found and it wasn't ours, and 0 if the indicator
+	 wasn't found at all.
+      2) The value of STARTP gets the offset of INDICATOR,
+      3) the value of ENDP gets the offset of the end of INDICATOR. */
+extern int page_indicator_owned_by (PAGE *page, char *indicator, char *tag,
+				    int *startp, int *endp, int search_start);
 #endif /* !_PAGES_H_ */
