@@ -1618,6 +1618,8 @@ mhtml_execute_function (UserFunction *uf, PFunArgs, char *attr)
 	      if (strcmp (packname, "local") == 0)
 		{
 		  Package *current_package = CurrentPackage;
+		  char *packname = current_package->name ?
+		    strdup (current_package->name) : (char *)NULL;
 		  char *x;
 
 		  CurrentPackage = symbol_get_package ((char *)NULL);
@@ -1634,7 +1636,14 @@ mhtml_execute_function (UserFunction *uf, PFunArgs, char *attr)
 		      bprintf_insert (page, start, "%s", x);
 		      *newstart += strlen (x);
 		    }
+
 		  xfree (x);
+		  if (packname)
+		    {
+		      current_package = symbol_get_package (packname);
+		      free (packname);
+		    }
+
 		  CurrentPackage = current_package;
 		}
 	      else
