@@ -38,6 +38,12 @@
 #  define LIBMHTML_INTERNAL 1
 #endif
 
+extern char LEFT_BRACKET, RIGHT_BRACKET;
+
+#if defined (METAHTML_PROFILER)
+# include "profiler.h"
+#endif
+
 typedef struct
 {
   int type;		/* Either user_MACRO, user_SUBST, or user_DEFUN. */
@@ -47,6 +53,9 @@ typedef struct
   char *body;		/* The body of the macro or subst. */
   char *packname;	/* Default package for the scope of this function. */
   char **named_parameters; /* Variables to bind during function invocation. */
+#if defined (METAHTML_PROFILER)
+  PROFILE_INFO *profile_info;
+#endif
 } UserFunction;
 
 /* Return a pointer to the UserFunction structure describing the user level
@@ -55,7 +64,7 @@ extern UserFunction *mhtml_find_user_function (char *name);
 
 #undef whitespace
 #define whitespace(c) \
-     (((c) == ' ') || ((c) == '\t') || ((c) == '\r') || ((c) == '\n'))
+	(((c) == ' ') || ((c) == '\t') || ((c) == '\r') || ((c) == '\n'))
 
 #undef return_sequence
 #define return_sequence(c, c1) \
@@ -64,8 +73,12 @@ extern UserFunction *mhtml_find_user_function (char *name);
 #if defined (LIBMHTML_INTERNAL)
 #define PACKAGE_INITIALIZER(name)
 
+/* A pointer to a function which takes a Package as an argument, and
+   initializes that package with Meta-HTML function pointers. */
+typedef void METAHTML_INITFUNC (Package *);
+
 #define var_present_p(pack, name) \
-    (symbol_lookup_in_package (pack, name) != (Symbol *)NULL)
+     (symbol_lookup_in_package (pack, name) != (Symbol *)NULL)
 
 /* Globally known variable holds onto the reserved words. */
 extern Package *mhtml_function_package;
@@ -95,9 +108,15 @@ typedef void PFunHandler (PFunArgs);
 typedef struct
 {
   char *tag;		/* The name of the function. */
-  int complexp;		/* Non-zero indicates <foo> ... </foo>.  */
+  int complexp;		/* Non-zero indicates <foo> ... </foo>.  In addition,
+			   a value of -1 here indicates a "weak" complex tag;
+			   the closing tag does not have to be present in
+			   that case. */
   int debug_level;	/* How much debugging to do. */
   PFunHandler *fun;	/* The code that handles this PAGEFUNC. */
+#if defined (METAHTML_PROFILER)
+  PROFILE_INFO *profile_info;
+#endif
 } PFunDesc;
 
 /* Return the primitive descriptor for TAG, or NULL if there is none. */
@@ -124,6 +143,7 @@ extern jmp_buf page_jmp_buffer;
 #define user_DEFUN 3
 
 #define user_WHITESPACE_DELETED	0x01
+#define user_WEAK_MACRO		0x02
 
 extern char *metahtml_copyright_string;
 
@@ -199,6 +219,15 @@ extern void mhtml_add_user_function (int type, char *name, char *body,
 extern char *mhtml_canonicalize_file_name (char *input, char *incpref,
 					   char *relpref);
 
+/* Same, but auto-handle the include and relative prefixes dependent on the
+   setting of isp::web-relative-pathnames.  Also evaluates ARGUMENT, so you
+   should call this function like:
+
+   fname = mhtml_canonicalize_file_name_argument (get_positional_arg (vars, 1))
+
+   and xfree() FNAME when you are done with it. */
+extern char *mhtml_canonicalize_file_name_argument (char *argument);
+
 /* Set the debugging level for the function named in SYM to
    be the value of SYM. */
 extern void mhtml_set_debugging_on (Symbol *sym);
@@ -214,4 +243,6 @@ extern int mhtml_all_digits (char *string);
 
 extern char *mhtml_base64decode (char *encoded, int *len);
 
-#endif (_PARSER_H_)
+extern PAGE *parser_top_page (void);
+
+#endif /*_PARSER_H_ */
