@@ -36,6 +36,8 @@ static void pf_read (PFunArgs);
 static void pf_write_package_file (PFunArgs);
 static void pf_read_package_file (PFunArgs);
 static void pf_switch_user (PFunArgs);
+static void pf_the_page (PFunArgs);
+static void pf_point (PFunArgs);
 
 PFunDesc prims_table[] = {
   { "%%EVAL",			0, 0, pf_eval },
@@ -43,6 +45,8 @@ PFunDesc prims_table[] = {
   { "%%WRITE-PACKAGE-FILE",	0, 0, pf_write_package_file },
   { "%%READ-PACKAGE-FILE",	0, 0, pf_read_package_file },
   { "%%SWITCH-USER",		0, 0, pf_switch_user },
+  { "%%THE-PAGE",		0, 0, pf_the_page },
+  { "%%POINT",			0, 0, pf_point },
   { (char *)NULL,		0, 0, (PFunHandler *)NULL }
 };
 
@@ -227,3 +231,42 @@ pf_switch_user (PFunArgs)
       *newstart += strlen (result);
     }
 }
+
+/* <%%the-page [varname]>
+   Places the current page into VARNAME as a binary variable, or,
+   returns the current page as text if VARNAME is not supplied. */
+static void
+pf_the_page (PFunArgs)
+{
+  char *varname = mhtml_evaluate_string (get_positional_arg (vars, 0));
+  PAGE *the_page = parser_top_page ();
+
+  if (empty_string_p (varname))
+    {
+      PAGE *contents = page_copy_page (the_page);
+      bprintf_insert (page, start, "%s", contents->buffer);
+      *newstart += contents->bindex;
+      page_free_page (contents);
+    }
+  else
+    {
+      Symbol *sym = symbol_remove (varname);
+      Datablock *block;
+      symbol_free (sym);
+
+      sym = symbol_intern (varname);
+      block = datablock_create (the_page->buffer, the_page->bindex);
+      sym->type = symtype_BINARY;
+      sym->values = (char **)block;
+    }
+
+  xfree (varname);
+}
+
+/* <%%point> --> Returns the current parser marker in the page.
+   CAVEAT!  Currently, can only be called at top level. */
+static void
+pf_point (PFunArgs)
+{
+  bprintf_insert (page, start, "%d", start);
+}
