@@ -86,6 +86,10 @@ static void pf_session_export_posted (PFunArgs);
 static void pf_session_import_posted (PFunArgs);
 #endif /* DEPRECATED_SESSION_COMMANDS */
 
+/* <set-session-db pathname> --> Dynamically change the location of the
+   file used to store session information. */
+static void pf_set_session_db (PFunArgs);
+
 PFunDesc sessionfunc_table[] =
 {
   /* The following functions deal with the session database. */
@@ -102,6 +106,7 @@ PFunDesc sessionfunc_table[] =
   { "SESSIONS-OF-KEY",	0, 0, pf_sessions_of_key },
   { "GET-SESSION-DATA", 0, 0, pf_get_session_data },
   { "SET-SESSION-DATA", 0, 0, pf_set_session_data },
+  { "SET-SESSION-DB",	0, 0, pf_set_session_db },
 
   /* Deprecate this as soon as possible. */
   { "SESSION-DATA-ALIST", 0, 0, pf_get_session_data },
@@ -752,6 +757,23 @@ pf_require_session (PFunArgs)
     bprintf_insert (page, start, "%s", code);
 }
 
+static void
+pf_set_session_db (PFunArgs)
+{
+  char *session_db_file = mhtml_evaluate_string (get_positional_arg (vars, 0));
+
+  if (empty_string_p (session_db_file))
+    {
+      xfree (session_db_file);
+      session_db_file = (char *)NULL;
+    }
+
+  set_session_database_location (session_db_file);
+  pagefunc_set_variable ("mhttpd::session-database-file", session_db_file);
+
+  xfree (session_db_file);
+}
+
 #if defined (DEPRECATED_SESSION_COMMANDS)
 static void
 pf_session_export_posted (PFunArgs)
