@@ -1022,6 +1022,36 @@ symbol_store_array (char *name, char **array)
     }
 }
 
+/* Return the canonicalized version of NAME.  This just strips out
+   array brackets.  Always returns a new string, unless the input
+   string is NULL. */
+char *
+symbol_canonical_name (char *name)
+{
+  char *result = (char *)NULL;
+
+  if (name != (char *)NULL)
+    {
+      register int i;
+
+      result = strdup (name);
+
+      for (i = 0; ((name[i] != '\0') && (name[i] != '[')); i++);
+
+      /* If there is an open-bracket here, see if there is a close. */
+      if (name[i] == '[')
+	{
+	  int zero = i;
+
+	  for (; ((name[i] != '\0') && (name[i] != ']')); i++);
+	  if (name[i] == ']')
+	    name[zero] = '\0';
+	}
+    }
+
+  return (result);
+}
+
 #if defined (TEST)
 
 int
