@@ -211,6 +211,11 @@ extern void symbol_notify_value (Symbol *symbol, int *address);
    pointed to by ARRAY. */
 extern void symbol_store_array (char *name, char **array);
 
+/* Return the canonicalized version of NAME.  This just strips out
+   array brackets.  Always returns a new string, unless the input
+   string is NULL. */
+extern char *symbol_canonical_name (char *name);
+
 extern int symbol_get_flags (Symbol *symbol);
 extern int symbol_get_flag (Symbol *symbol, int flag);
 extern void symbol_set_flag (Symbol *symbol, int flag);
