@@ -33,6 +33,7 @@
 #endif
 #include <unistd.h>
 #include <stdlib.h>
+#include <sys/types.h>
 #include <ctype.h>
 #include <string.h>
 #include <netdb.h>
@@ -46,7 +47,7 @@
 #include <arpa/inet.h>
 #endif
 
-#if defined (sparc) || defined (__linux__) || defined (sgi) || defined (Solaris) || defined (__WINNT__) || defined (hpux)
+#if !defined (HAVE_TYPE_SIG_T)
 typedef void (*sig_t) (int);
 #endif
 
