@@ -40,9 +40,7 @@ rl_insert_close (int count, int invoking_key)
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/types.h>
-#if defined (FD_SET)
-#  include <sys/time.h>
-#endif /* FD_SET */
+#include <sys/time.h>
 #include "readline.h"
 
 extern int rl_explicit_arg;
@@ -106,6 +104,7 @@ find_matching_open (char *string, int from, int closer)
     case ']': opener = '['; break;
     case '}': opener = '{'; break;
     case ')': opener = '('; break;
+    case '>': opener = '<'; break;
     default:
       return (-1);
     }
