@@ -39,6 +39,8 @@ static char *mhtml_version_string = "";
 static char *mhtml_version_string = MHTML_VERSION_STRING;
 #endif
 
+static int call_bootstrap = 1;
+
 #if !defined (macintosh)
 extern char **environ;
 #endif /* !macintosh */
@@ -100,7 +102,8 @@ prep_for_page_process (PAGE *page, int argc, char *argv[])
 {
   register int i;
 
-  bootstrap_metahtml (0);
+  if (call_bootstrap)
+    bootstrap_metahtml (0);
 
   if (page && page->buffer)
     {
@@ -179,7 +182,9 @@ parse_program_args (int argc, char *argv[])
 
 	  pagefunc_set_variable (name, value);
 	}
-      else if (!filename && (*arg != "-"))
+      else if (!filename && (strcmp (arg, "-z") == 0))
+	call_bootstrap = 0;
+      else if (!filename && (*arg != '-'))
 	filename = arg;
       else if (filename)
 	{
