@@ -95,6 +95,13 @@ static int servers_to_fork = 0;
 /* Non-zero means run once under inetd, and exit. */
 static int once_and_exit = 0;
 
+#define MHTTPD_DNS_CACHE "/tmp/mhttpd-dns.cache"
+
+#if defined (MHTTPD_DNS_CACHE)
+/* Non-zero means lookup and save DNS information in a local cache file. */
+static int mhttpd_cache_dns = 0;
+#endif
+
 /* Forward declarations. */
 static void parse_program_args (int argc, char *argv[]);
 static void loop_over_connections (void);
@@ -162,7 +169,16 @@ main (int argc, char *argv[])
 	    temp++;
 	  else
 	    temp = prefix;
-	  sprintf (temp, "mhttpd.pid");
+
+	  {
+	    char *pid_filename =
+	      pagefunc_get_variable ("mhttpd::pid-filename");
+
+	    if (!empty_string_p (pid_filename))
+	      sprintf (temp, "%s", pid_filename);
+	    else
+	      sprintf (temp, "mhttpd.pid");
+	  }
 
 	  pid_stream = fopen (prefix, "w");
 	  if (pid_stream != (FILE *)NULL)
@@ -260,6 +276,9 @@ static char *deletable_variables[] =
   "mhttpd::per-request-function",
   "mhttpd::session-database-file",
   "mhttpd::get-remote-ident",
+#if defined (MHTTPD_DNS_CACHE)
+  "mhttpd::cache-dns",
+#endif
 
   (char *)NULL
 };
@@ -484,6 +503,14 @@ index.html\nhome.html");
   set_session_database_location
     (pagefunc_get_variable ("mhttpd::session-database-file"));
 
+#if defined (MHTTPD_DNS_CACHE)
+  temp = pagefunc_get_variable ("mhttpd::cache-dns");
+  if (empty_string_p (temp))
+    mhttpd_cache_dns = 0;
+  else
+    mhttpd_cache_dns = 1;
+#endif
+
   if (first_time)
     first_time = 0;
   else
@@ -575,7 +602,6 @@ initialize_server ()
     char *key = pagefunc_get_variable ("mhtml::activation-key");
     if (check_activation_key (key) == 0)
       exit (1);
-    symbol_free (symbol_remove ("mhtml::activation-key"));
   }
 #endif /* CHECK_ACTIVATION */
 
@@ -1204,12 +1230,17 @@ loop_over_connections (void)
 
 	  if (!debug_mode && !know_my_client)
 	    {
+#if defined (MHTTPD_DNS_CACHE)
+	      char dns_cached_result[256];
+	      int cache_found = 0;
+#endif
 	      struct sockaddr_in client;
 
 	      if (getpeername
 		  (connection, (struct sockaddr *)&client, &sock_size) != -1)
 		{
 		  struct hostent *client_info = (struct hostent *)NULL;
+		  char *client_info_name = (char *)NULL;
 		  long addr =  client.sin_addr.s_addr;
 		  const char *x = (const char *)&addr;
 		  char *addr_rep = (char *)xmalloc (16);
@@ -1223,15 +1254,97 @@ loop_over_connections (void)
 			   (unsigned char)x[3]);
 
 		  req->requester_addr = addr_rep;
+
 		  if ((get_remote_host == (char *)NULL) ||
 		      (strcasecmp (get_remote_host, "true") == 0))
-		    client_info = gethostbyaddr (x, 4, AF_INET);
+		    {
+#if defined (MHTTPD_DNS_CACHE)
+		      if (mhttpd_cache_dns)
+			{
+			  DBFILE db;
 
-		  if (client_info)
-		    req->requester = strdup (client_info->h_name);
+			  db = database_open (MHTTPD_DNS_CACHE, DB_READER);
+
+			  if (db != (DBFILE)NULL)
+			    {
+			      DBOBJ key, *val;
+
+			      key.data = (req->requester_addr);
+			      key.length = 1 + strlen (key.data);
+			      val = database_fetch (db, &key);
+
+			      if (val != (DBOBJ *)NULL)
+				{
+				  if (val->data)
+				    {
+				      cache_found++;
+				      strncpy (dns_cached_result,
+					       val->data, val->length);
+				      dns_cached_result[val->length] = '\0';
+				      client_info_name = dns_cached_result;
+				      free (val->data);
+				    }
+				  free (val);
+				}
+			      database_close (db);
+			    }
+			}
+
+		      if (client_info_name == (char *)NULL)
+#endif /* MHTTPD_DNS_CACHE */
+			{
+			  client_info = gethostbyaddr (x, 4, AF_INET);
+			  if (client_info)
+			    client_info_name = (char *)client_info->h_name;
+			}
+		    }
+
+		  if (client_info_name)
+		    {
+		      req->requester = strdup (client_info_name);
+
+		      /* Some sneaky bastards don't return a real hostname.
+			 When that happens, use the address instead of the
+			 name. */
+		      {
+			register int i, dots=0;
+
+			for (i = 0; req->requester[i] != '\0'; i++)
+			  if (req->requester[i] == '.')
+			    dots++;
+
+			if (dots < 2)
+			  {
+			    free (req->requester);
+			    req->requester = strdup (addr_rep);
+			  }
+		      }
+		    }
 		  else
 		    req->requester = strdup (addr_rep);
 
+#if defined (MHTTPD_DNS_CACHE)
+		  if (mhttpd_cache_dns && !cache_found)
+		    {
+		      /* I don't really want to save the data in this
+			 process, but I can't see a relatively inexpensive
+			 way to do it otherwise. */
+		      DBFILE db;
+
+		      db = database_open (MHTTPD_DNS_CACHE, DB_WRCREAT);
+		      if (db != (DBFILE)NULL)
+			{
+			  DBOBJ key, val;
+			  key.data = req->requester_addr;
+			  val.data = client_info_name;
+			  key.length = 1 + strlen (key.data);
+			  val.length = 1 + strlen (val.data);
+			  database_store (db, &key, &val);
+			  database_close (db);
+			}
+		    }
+#endif /* MHTTPD_DNS_CACHE */
+
 #if defined (I_UNDERSTAND_IDENT)
 		  /* Do the IDENT lookup if that is requested. */
 		  if (pagefunc_get_variable ("mhttpd::get-remote-ident"))
